==> cms-db_v0.9.tar.gz: admin/variables.php <==
<?php
/*  cms-db  Copyright (C) 2007-2011 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

define('cms-db', 'backend');

include('checkuser.inc.php');
checkuser('');
include('locale.inc.php');
$locale = new LocalizingClass('variables');
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title><?php locale('title') ?></title>
<meta http-equiv="content-type" content="text/html; charset=utf-8" />
<link rel="stylesheet" type="text/css" href="style.css">
</head>
<body>

<h1><?php locale('title') ?></h1>
<p>
	<?php locale('desc') ?>
</p>
<h2><?php locale('title_variables-menu') ?></h2>
<dl>
	<?php
	function displayHeading($title) {
		echo '</dt><h2>'.locale('title_variables-'.$title,true).'</h2><dt>';
	}
	function displayVariableDescription($variable, $desc, $paragraph) {
		echo '<dt>'.$variable.' <img alt=" " src="p_'.$paragraph.'.png" style="vertical-align: middle" title="'.locale('desc_p-'.$paragraph,true).'" /></dt>';
		echo '<dd>'.locale($desc,true).'</dd>';
	}
	displayVariableDescription('%%TOPMENU%%', 'desc_topmenu', 'disallowed');
	displayVariableDescription('%%COMPLETESUBMENU%%', 'desc_completesubmenu', 'disallowed');
	displayVariableDescription('%%FOLDINGSUBMENU%%', 'desc_foldingsubmenu', 'disallowed');
	displayVariableDescription('%%COMPLETEMENU%%', 'desc_completemenu', 'disallowed');
	displayVariableDescription('%%FOLDINGMENU%%', 'desc_foldingmenu', 'disallowed');
	displayHeading('contentstructure');
	displayVariableDescription('%%PAGESEARCH%%', 'desc_pagesearch', 'disallowed');
	displayVariableDescription('%%PAGETITLE%%', 'desc_pagetitle', 'allowed');
	displayVariableDescription('%%FULLTITLE%%', 'desc_fulltitle', 'allowed');
	displayVariableDescription('%%BREADCRUMBS%%', 'desc_breadcrumbs', 'allowed');
	displayVariableDescription('%%PAGECONTENT%%', 'desc_pagecontent', 'disallowed');
	displayVariableDescription('%%LASTEDIT%%', 'desc_lastedit', 'allowed');
	displayVariableDescription('%%PAGECOUNT%%', 'desc_pagecount', 'allowed');
	displayVariableDescription('%%COUNTER%%', 'desc_counter', 'allowed');
	displayVariableDescription('%%SITEMAP%%', 'desc_sitemap', 'alone');
	displayVariableDescription('%%SECTIONLIST%%', 'desc_sectionlist', 'alone');
	displayHeading('dynamic');
	displayVariableDescription('%%MAILFORM-ADDRESS%%', 'desc_mailform', 'alone');
	displayVariableDescription('%%GUESTBOOK%%', 'desc_guestbook', 'alone');
	displayHeading('blog');
	displayVariableDescription('%%BLOG%%', 'desc_blog', 'alone');
	displayVariableDescription('%%LATESTBLOGARTICLES-PAGE%%', 'desc_latestblogarticles', 'alone');
	displayVariableDescription('%%TAGCLOUD-PAGE%%', 'desc_tagcloud', 'alone');
	displayVariableDescription('%%COMPLETEBLOGFEED-PAGE%%', 'desc_completeblogfeed', 'allowed');
	//displayVariableDescription('%%TAGBLOGFEED-PAGE%%', 'desc_tagblogfeed', 'allowed');
	displayVariableDescription('%%ALLBLOGFEEDS-PAGE%%', 'desc_allblogfeeds', 'alone');
	displayVariableDescription('%%CONTEXTBLOGFEEDS%%', 'desc_contextblogfeeds', 'alone');
	displayHeading('misc');
	displayVariableDescription('%%LOGINFORM%%', 'desc_loginform', 'alone');
	displayVariableDescription('%%INCLUDE-NAME%% / %%LATEINCLUDE-NAME%%', 'desc_include', 'alone');
	displayVariableDescription('%%REDIRECT-URL%%', 'desc_redirect', 'allowed');
	displayVariableDescription('%%FORCELANGUAGE-LANGCODE%%', 'desc_forcelanguage', 'allowed');
	displayVariableDescription('%%URLBEFORE%%, %%URLAFTER%%, %%URLABSOLUTE%%', 'desc_urlsettings', 'allowed');
	displayVariableDescription('%%COMPLETEURL%%', 'desc_completeurl', 'allowed');
	displayVariableDescription('%%CONDITION-(COND)%% ... %%ENDCONDITION%%', 'desc_condition', 'needed');
	?>
</dl>
<h2><?php locale('title_variables-legend') ?></h2>
<p>
	<img alt=" " src="p_allowed.png" style="vertical-align: middle" alt="" /> <?php locale('desc_p-allowed') ?><br />
	<img alt=" " src="p_alone.png" style="vertical-align: middle" alt="" /> <?php locale('desc_p-alone') ?><br />
	<img alt=" " src="p_needed.png" style="vertical-align: middle" alt="" /> <?php locale('desc_p-needed') ?><br />
	<img alt=" " src="p_disallowed.png" style="vertical-align: middle" alt="" /> <?php locale('desc_p-disallowed') ?>
</p>

</body>
</html>

==> cms-db_v0.9.3.tar.gz: admin/variables.php <==
<?php
/*  cms-db  Copyright (C) 2007-2011 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

define('cms-db', 'backend');

require_once('path.inc.php');
require_once(CDB_PATH_ADMIN.'/checkphp.inc.php');
require_once(CDB_PATH_ADMIN.'/checkuser.inc.php');

checkuser('');
require_once(CDB_PATH_ADMIN.'/locale.inc.php');
$locale = new LocalizingClass('variables');
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title><?php locale('title') ?></title>
<meta http-equiv="content-type" content="text/html; charset=utf-8" />
<link rel="stylesheet" type="text/css" href="style.css">
</head>
<body>

<h1><?php locale('title') ?></h1>
<p>
	<?php locale('desc') ?>
</p>
<h2><?php locale('title_variables-menu') ?></h2>
<dl>
	<?php
	function displayHeading($title) {
		echo '</dt><h2>'.locale('title_variables-'.$title,true).'</h2><dt>';
	}
	function displayVariableDescription($variable, $desc, $paragraph) {
		echo '<dt>'.$variable.' <img alt=" " src="p_'.$paragraph.'.png" style="vertical-align: middle" title="'.locale('desc_p-'.$paragraph,true).'" /></dt>';
		echo '<dd>'.locale($desc,true).'</dd>';
	}
	displayVariableDescription('%%TOPMENU%%', 'desc_topmenu', 'disallowed');
	displayVariableDescription('%%COMPLETESUBMENU%%', 'desc_completesubmenu', 'disallowed');
	displayVariableDescription('%%FOLDINGSUBMENU%%', 'desc_foldingsubmenu', 'disallowed');
	displayVariableDescription('%%COMPLETEMENU%%', 'desc_completemenu', 'disallowed');
	displayVariableDescription('%%FOLDINGMENU%%', 'desc_foldingmenu', 'disallowed');
	displayHeading('contentstructure');
	displayVariableDescription('%%PAGESEARCH%%', 'desc_pagesearch', 'disallowed');
	displayVariableDescription('%%PAGETITLE%%', 'desc_pagetitle', 'allowed');
	displayVariableDescription('%%FULLTITLE%%', 'desc_fulltitle', 'allowed');
	displayVariableDescription('%%BREADCRUMBS%%', 'desc_breadcrumbs', 'allowed');
	displayVariableDescription('%%PAGECONTENT%%', 'desc_pagecontent', 'disallowed');
	displayVariableDescription('%%LASTEDIT%%', 'desc_lastedit', 'allowed');
	displayVariableDescription('%%PAGECOUNT%%', 'desc_pagecount', 'allowed');
	displayVariableDescription('%%COUNTER%%', 'desc_counter', 'allowed');
	displayVariableDescription('%%SITEMAP%%', 'desc_sitemap', 'alone');
	displayVariableDescription('%%SECTIONLIST%%', 'desc_sectionlist', 'alone');
	displayHeading('dynamic');
	displayVariableDescription('%%MAILFORM-ADDRESS%%', 'desc_mailform', 'alone');
	displayVariableDescription('%%GUESTBOOK%%', 'desc_guestbook', 'alone');
	displayHeading('blog');
	displayVariableDescription('%%BLOG%%', 'desc_blog', 'alone');
	displayVariableDescription('%%LATESTBLOGARTICLES-PAGE%%', 'desc_latestblogarticles', 'alone');
	displayVariableDescription('%%TAGCLOUD-PAGE%%', 'desc_tagcloud', 'alone');
	displayVariableDescription('%%COMPLETEBLOGFEED-PAGE%%', 'desc_completeblogfeed', 'allowed');
	//displayVariableDescription('%%TAGBLOGFEED-PAGE%%', 'desc_tagblogfeed', 'allowed');
	displayVariableDescription('%%ALLBLOGFEEDS-PAGE%%', 'desc_allblogfeeds', 'alone');
	displayVariableDescription('%%CONTEXTBLOGFEEDS%%', 'desc_contextblogfeeds', 'alone');
	displayHeading('misc');
	displayVariableDescription('%%LOGINFORM%%', 'desc_loginform', 'alone');
	displayVariableDescription('%%INCLUDE-NAME%% / %%LATEINCLUDE-NAME%%', 'desc_include', 'alone');
	displayVariableDescription('%%REDIRECT-URL%%', 'desc_redirect', 'allowed');
	displayVariableDescription('%%FORCELANGUAGE-LANGCODE%%', 'desc_forcelanguage', 'allowed');
	displayVariableDescription('%%URLBEFORE%%, %%URLAFTER%%, %%URLABSOLUTE%%', 'desc_urlsettings', 'allowed');
	displayVariableDescription('%%COMPLETEURL%%', 'desc_completeurl', 'allowed');
	displayVariableDescription('%%CONDITION-(COND)%% ... %%ENDCONDITION%%', 'desc_condition', 'needed');
	?>
</dl>
<h2><?php locale('title_variables-legend') ?></h2>
<p>
	<img alt=" " src="p_allowed.png" style="vertical-align: middle" alt="" /> <?php locale('desc_p-allowed') ?><br />
	<img alt=" " src="p_alone.png" style="vertical-align: middle" alt="" /> <?php locale('desc_p-alone') ?><br />
	<img alt=" " src="p_needed.png" style="vertical-align: middle" alt="" /> <?php locale('desc_p-needed') ?><br />
	<img alt=" " src="p_disallowed.png" style="vertical-align: middle" alt="" /> <?php locale('desc_p-disallowed') ?>
</p>

</body>
</html>
